
Viva Insights uses email and calendar activities that are stored in a person's Office 365 account to reveal internal and external collaboration trends. However, a person's calendar and email can contain a diverse set of activities (such as personal meetings or appointments, social activities, all-day training meetings, and so forth) that are not relevant to work-related collaboration, and, if included in the metrics, would skew query results.  

This section analyses the subject lines from the supplied meeting query, to identify if common exclusion terms are present in your data (e.g. happy hour, yoga class, team dinner, etc.). For more information, please visit [meeting exclusion rules](https://docs.microsoft.com/en-us/Workplace-Analytics/tutorials/meeting-exclusions-intro).    


