Introduction =====================================

# Employee Wellbeing Report

Microsoft Viva | Organisational Insights

Employee wellbeing has demonstrated the ability to improve employee engagement, retention and productivity within a company.
Get insights into employee wellbeing across your company and uncover opportunities to improve work life balance, flexible working opportunities, organizational resilience and a sense of community.

#### Table of Contents
1. Collaboration 2. Balance 3. Urgency 4. Flexibility
5. Activity Patterns 6. Focus 7. Community 8. Informal communication

Start exploring