## Introduction

This report allows you to review the quality of the Viva Insights data available and highlights specific issues that may require your attention before starting analysis. This report is structured in three sections:  

1. Viva Insights Settings
2. Organizational Data Quality
3. M365 Data Quality  

The Microsoft Team behind Viva Insights has developed a series of data checks for each section. For the areas that have issues, we also provide you with suggestions to further clean up the data before performing additional analysis.   

This report will automatically conduct certain data quality tests. Results will be indicated as a `[Pass]` or `[Warning]` throughout the report. `[Warning]` messages will direct you to items that need your attention and potential action.     

For additional information about Viva Insights, including metric definitions, please visit our [official documentation](https://learn.microsoft.com/en-us/viva/insights/advanced/reference/metrics).  

---
