
It is recommended for Viva Insights administrators to keep up to date the organizational data that is uploaded into Workplace Analytics. These updates help guarantee that relevant changes in the organizational structure are reflected in the system, that the collaboration data of new joiners is captured, and that all Office 365 data flows are attributed to the right teams and departments (even when some employees may change roles or be promoted internally).  

The following chart shows the observed mobility of employees between teams in your organization. Lack of changes could indicate that the organizational data has not been frequently updated during the period under consideration.  
 
