
To minimize privacy risk, queries from Viva Insights are anonymized. We also recommend that during analysis,  collaboration patterns from teams or departments are reported in an aggregated way, respecting a minimum-group-size privacy threshold (your Viva Insights Administration has already defined a minimum-group-size rule that affects Explore charts and in Plans within Viva Insights).  

The default minimum-group setting in this report is *five*, but this setting can be changed according to the privacy requirements of your organization. Re-run this report using the *mingroup* parameter to use a custom minimum group size setting.
