% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/supporting_functions.R
\name{pad2}
\alias{pad2}
\title{Create the two-digit zero-padded format}
\usage{
pad2(x)
}
\arguments{
\item{x}{numeric value or vector with maximum two characters.}
}
\value{
Numeric value containing two-digit zero-padded values.
}
\description{
Create the two-digit zero-padded format
}
